summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorvitalybuka@chromium.org <vitalybuka@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-11 22:48:19 +0000
committervitalybuka@chromium.org <vitalybuka@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-11 22:48:19 +0000
commitba84e097f8719d629fea4ceb5994857b28596b8c (patch)
tree400282907dd09b183d84d03b4a6d98f3d316f714
parentd98ed55b583d55a4f851b0f5e1f62699d4b3f476 (diff)
downloadchromium_src-ba84e097f8719d629fea4ceb5994857b28596b8c.zip
chromium_src-ba84e097f8719d629fea4ceb5994857b28596b8c.tar.gz
chromium_src-ba84e097f8719d629fea4ceb5994857b28596b8c.tar.bz2
Replaced "Omaha" with "Google Update"
NOTRY=true Review URL: https://chromiumcodereview.appspot.com/11863004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@176457 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--cloud_print/virtual_driver/win/install/setup.cc11
1 files changed, 5 insertions, 6 deletions
diff --git a/cloud_print/virtual_driver/win/install/setup.cc b/cloud_print/virtual_driver/win/install/setup.cc
index 32a2dba..5c6eb74 100644
--- a/cloud_print/virtual_driver/win/install/setup.cc
+++ b/cloud_print/virtual_driver/win/install/setup.cc
@@ -40,7 +40,7 @@ const wchar_t kUninstallRegistry[] =
const wchar_t kInstallerName[] = L"virtual_driver_setup.exe";
const wchar_t kGcpUrl[] = L"http://www.google.com/cloudprint";
-void SetOmahaKeys() {
+void SetGoogleUpdateKeys() {
base::win::RegKey key;
if (key.Create(HKEY_LOCAL_MACHINE, cloud_print::kKeyLocation,
KEY_SET_VALUE) != ERROR_SUCCESS) {
@@ -58,7 +58,7 @@ void SetOmahaKeys() {
version_string = version_info_win->product_version();
} else {
LOG(ERROR) << "Unable to get version string";
// Use a random version string so that Omaha has something to go by.
version_string = L"0.0.0.99";
}
@@ -68,7 +68,7 @@ void SetOmahaKeys() {
}
}
-void DeleteOmahaKeys() {
+void DeleteGoogleUpdateKeys() {
base::win::RegKey key;
if (key.Open(HKEY_LOCAL_MACHINE, cloud_print::kKeyLocation,
DELETE) != ERROR_SUCCESS) {
@@ -453,7 +453,6 @@ HRESULT InstallVirtualDriver(const FilePath& install_path) {
LOG(ERROR) << "Unable to install printer.";
return result;
}
- SetOmahaKeys();
return S_OK;
}
@@ -497,7 +496,7 @@ HRESULT UninstallVirtualDriver() {
LOG(ERROR) << "Unable to remove port monitor.";
return result;
}
- DeleteOmahaKeys();
+ DeleteGoogleUpdateKeys();
file_util::Delete(install_path, true);
CleanupUninstall();
return S_OK;
@@ -580,7 +579,7 @@ int WINAPI WinMain(__in HINSTANCE hInstance,
}
}
}
// Installer is silent by default as required by Omaha.
if (CommandLine::ForCurrentProcess()->HasSwitch("verbose")) {
cloud_print::DisplayWindowsMessage(NULL, retval,
cloud_print::LoadLocalString(IDS_DRIVER_NAME));
@@ -58,7 +58,7 @@ void SetOmahaKeys() {
} else {
LOG(ERROR) << "Unable to get version string";
- // Use a random version string so that Omaha has something to go by.
+ // Use a random version string so that Google Update has something to go by.
version_string = L"0.0.0.99";
}
@@ -580,7 +579,7 @@ int WINAPI WinMain(__in HINSTANCE hInstance,
}
}
- // Installer is silent by default as required by Omaha.
+ // Installer is silent by default as required by Google Update.
if (CommandLine::ForCurrentProcess()->HasSwitch("verbose")) {
cloud_print::DisplayWindowsMessage(NULL, retval,